@@ -133,7 +133,8 @@ coeftest(fit3, vcov. = vcovCL, cluster = ~subclass)["A",,drop=FALSE]
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #Generalized linear model without covariates
-fit4 <- glm(Y_B ~ A, data = md, family = binomial(link = "logit"))
+fit4 <- glm(Y_B ~ A, data = md, weights = weights, 
+            family = binomial(link = "logit"))
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #Cluster-robust standard errors
@@ -189,7 +190,7 @@ boot.ci(boot_est, type = "bca")
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #Cox Regression for marginal HR
 coxph(Surv(Y_S) ~ A, data = md, robust = TRUE, 
-      cluster = subclass)
+      weights = weights, cluster = subclass)
 
 ## ---- eval = FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #  #Block bootstrap confidence interval
@@ -211,7 +212,7 @@ coxph(Surv(Y_S) ~ A, data = md, robust = TRUE,
 #    md_boot <- md[ids,]
 #  
 #    #Effect estimation
-#    cox_fit_boot <- coxph(Surv(Y_S) ~ A, data = md_boot)
+#    cox_fit_boot <- coxph(Surv(Y_S) ~ A, data = md_boot, weights = weights)
 #  
 #    #Compute the marginal HR by exponentiating the coefficient
 #    #on treatment
@@ -529,6 +530,42 @@ fitcond <- lm(Y_B ~ A + X1 + X2 + X3 + X4 + X5 +
 coeftest(fitcond, vcov. = vcovCL, cluster = ~subclass)["A",,drop = FALSE]
 exp(coef(fitcond)["A"])
 
+## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+mP <- matchit(A ~ X1 + X2 + X5*X3 + X4 + 
+                X5*X6 + X7 + X5*X8 + X9, data = d,
+              exact = ~X5, method = "nearest")
+mP
+
+## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+mdP <- match.data(mP)
+
+fitP <- lm(Y_C ~ A * X5, data = mdP, weights = weights)
+
+coeftest(fitP, vcov. = vcovCL, cluster = ~subclass)
+
+## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+d_X5_0 <- subset(d, X5 == 0)
+d_X5_1 <- subset(d, X5 == 1)
+
+## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+mS0 <- matchit(A ~ X1 + X2 + X3 + X4 + 
+                 X6 + X7 + X8 + X9, data = d_X5_0,
+               method = "nearest")
+
+mS1 <- matchit(A ~ X1 + X2 + X3 + X4 + 
+                 X6 + X7 + X8 + X9, data = d_X5_1,
+               method = "nearest")
+
+## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+mdS0 <- match.data(mS0)
+mdS1 <- match.data(mS1)
+
+mdS <- rbind(mdS0, mdS1)
+
+fitS <- lm(Y_C ~ A * X5, data = mdS, weights = weights)
+
+coeftest(fitS, vcov. = vcovCL, cluster = ~subclass)
+
 ## ---- eval = FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #  #Generatng data similar to Austin (2009) for demonstrating treatment effect estimation
 #  gen_X <- function(n) {
